import { Result } from "../util/result";
import { StructureFlowRegime } from "./structure";
import { StructureWeirFree } from "./structure_weir_free";
import { Villemonte } from "./villemonte";

export class StructureWeirVillemonte extends StructureWeirFree {

    /**
     * Calcul analytique Q = f(Cd, L, h1, h2, W) seuil dénoyé
     * @param sVarCalc Variable à calculer (doit être "Q")
     */
    public CalcQ(): Result {
        const r: Result = super.CalcQ();
        if (r.ok && r.extraResults.ENUM_StructureFlowRegime !== StructureFlowRegime.FREE) {
            r.vCalc = Villemonte(this.prms.h1.v, this.prms.h2.v, 1.5) * r.vCalc;
        }
        return r;
    }

    protected getFlowRegime() {
        if (this.prms.Z2.v <= this.prms.ZDV.v) {
            return StructureFlowRegime.FREE;
        } else {
            // La réduction de débit s'applique dès que Z2 > ZDV (Villemonte, 1946)
            if (this.prms.h2.v < 2 / 3 * this.prms.h1.v) {
                // Yc = 2 / 3 * H1 (Jameson, 1925)
                return StructureFlowRegime.PARTIAL;
            }
            return StructureFlowRegime.SUBMERGED;
        }
    }
}
